Package: CausalR
Type: Package
Title: Causal network analysis methods
Version: 1.45.0
Date: 2016-11-14
Author: Glyn Bradley, Steven Barrett, Chirag Mistry, Mark Pipe, David Wille, David Riley, Bhushan Bonde, Peter Woollard
Maintainer: Glyn Bradley <glyn.x.bradley@gsk.com>, Steven Barrett <steven.j.barrett@gsk.com>
Description: Causal network analysis methods for regulator prediction and network reconstruction from genome scale data.
Depends: R (>= 3.2.0)
Imports: igraph
Suggests: knitr, RUnit, BiocGenerics
VignetteBuilder: knitr
biocViews: ImmunoOncology, SystemsBiology, Network, GraphAndNetwork,
        Network Inference, Transcriptomics, Proteomics,
        DifferentialExpression, RNASeq, Microarray
License: GPL (>= 2)
NeedsCompilation: no
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/CausalR
git_branch: devel
git_last_commit: 41ac129
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-28 21:40:02 UTC; biocbuild
