# Generated by roxygen2: do not edit by hand

export(AnalysePredictionsList)
export(CalculateEnrichmentPValue)
export(CalculateSignificance)
export(CalculateSignificanceUsingCubicAlgorithm)
export(CalculateSignificanceUsingCubicAlgorithm1b)
export(CalculateSignificanceUsingQuarticAlgorithm)
export(CompareHypothesis)
export(CreateCCG)
export(CreateCG)
export(GetNodeName)
export(GetNumberOfPositiveAndNegativeEntries)
export(GetShortestPathsFromCCG)
export(MakePredictions)
export(MakePredictionsFromCCG)
export(MakePredictionsFromCG)
export(PlotGraphWithNodeNames)
export(RankTheHypotheses)
export(ReadExperimentalData)
export(ScoreHypothesis)
export(WriteAllExplainedNodesToSifFile)
export(WriteExplainedNodesToSifFile)
export(runSCANR)
import(igraph)
