% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CheckPossibleValuesAreValid.r
\name{CheckPossibleValuesAreValid}
\alias{CheckPossibleValuesAreValid}
\title{check possible values are valid}
\usage{
CheckPossibleValuesAreValid(predictionDataStats, experimentalDataStats,
  possibleValues)
}
\arguments{
\item{predictionDataStats}{a vector of predicted results}

\item{experimentalDataStats}{a vector of observed experimental results}

\item{possibleValues}{a vector of possible values  n++, n+-, n-+ and n--}
}
\value{
TRUE if and only if the given vector of possible values is valid
}
\description{
Checks if the a given set of possible values for n++, n+-, n-+ and n-- are agree with the predicted and experimental
data
}

