% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CalculateWeightGivenValuesInThreeByThreeContingencyTable.r
\name{CalculateWeightGivenValuesInThreeByThreeContingencyTable}
\alias{CalculateWeightGivenValuesInThreeByThreeContingencyTable}
\title{calculate weight given values in three-by-three contingency table}
\usage{

  CalculateWeightGivenValuesInThreeByThreeContingencyTable(threeByThreeContingencyTable,
  logOfFactorialOfPredictionListStats, returnlog = FALSE)
}
\arguments{
\item{threeByThreeContingencyTable}{a 3x3 contingency table}

\item{logOfFactorialOfPredictionListStats}{log of Factorial of prediction statistics}

\item{returnlog}{should the result be returned as a log value. Default is FALSE.}
}
\value{
a D-value (or weight)
}
\description{
Given the values in the three by three contingency table and the values of the number of positive/negative/non-significant predictions (q+, q-, q0) this function calculates the D-value (or weight).
}

