% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetNumberOfPositiveAndNegativeEntries.r
\name{GetNumberOfPositiveAndNegativeEntries}
\alias{GetNumberOfPositiveAndNegativeEntries}
\title{counts the number of positive and negative entries}
\usage{
GetNumberOfPositiveAndNegativeEntries(dataList)
}
\arguments{
\item{dataList}{an array or dataframe in which the second column is numeric}
}
\value{
a vector of two components, the first of which giving the number of +1 entries, the second the number of -1's.
}
\description{
Counts the number of entries in the in the second column of an input table that are +1 or -1.
}
\examples{
expData<-read.table(system.file(package='CausalR', 'extdata', 'testData.txt'))
GetNumberOfPositiveAndNegativeEntries(expData)
}
\concept{
CausalR
}

