% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CalculateTotalWeightForAllContingencyTables.r
\name{CalculateTotalWeightForAllContingencyTables}
\alias{CalculateTotalWeightForAllContingencyTables}
\title{calculate total weight for all contingency tables}
\usage{
CalculateTotalWeightForAllContingencyTables(experimentalDataStats,
  returnlog = FALSE)
}
\arguments{
\item{experimentalDataStats}{a vector containing the values n+, n- and n0, the number of positive/negative/non-significant (or contradictory) transcripts in the results}

\item{returnlog}{whether the result should be returned as a log. Default is FALSE.}
}
\value{
a D-value or weight
}
\description{
Calculates the total weights or D-values for all possible  contingency tables. This value can be  used to calculate the p-value
}

