% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ComputeFinalDistribution.r
\name{ComputeFinalDistribution}
\alias{ComputeFinalDistribution}
\title{compute final distribution}
\usage{
ComputeFinalDistribution(resultsMatrix)
}
\arguments{
\item{resultsMatrix}{a matrix containing the scores and weights from which the distribution is to be calculated}
}
\value{
distributionMatrix  a matrix containing the reference distribution for the score
}
\description{
Computes a final reference distribution of the score used to compute the final p-value.
}

