% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetMaxDValueForAThreeByTwoFamily.r
\name{GetMaxDValueForAThreeByTwoFamily}
\alias{GetMaxDValueForAThreeByTwoFamily}
\title{get maximum D value for three-by-two a family}
\usage{
GetMaxDValueForAThreeByTwoFamily(r_p, r_m, r_z, n_p, n_m, predictionListStats,
  logOfFactorialOfPredictionListStats, returnlog = FALSE)
}
\arguments{
\item{r_p}{a r+ row sum from the prediction-observation matrix}

\item{r_m}{a  r- row sum from the prediction-observation matrix}

\item{r_z}{a  r0 row sum from the prediction-observation matrix}

\item{n_p}{a number of predicted increases from the prediction-observation matrix}

\item{n_m}{a number of predicted decreases  from the prediction-observation matrix}

\item{predictionListStats}{a vector contain the number of postive, negative and non-significant/contradictory predictions: q+, q- and q0.}

\item{logOfFactorialOfPredictionListStats}{a vector containing the log of the factorial for each element in the predictionListStats object}

\item{returnlog}{whether or not the maximum D value should be returned as a log (TRUE). Otherwise a non-logged value is returned.}
}
\value{
Maximum D_fam Value
}
\description{
Returns the maximum D value for a particular family as described as D_fam 
 on pages 6 and 7 of  Assessing Statistical Significance of Causal Graphs in Assessing Statistical Signifcance of Causal Graphs
}
\references{
L Chindelevitch et al.
Assessing statistical significance in causal graphs.
BMC Bioinformatics, 13(35), 2012.
}

