% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetScoresWeightsMatrix.r
\name{GetScoresWeightsMatrix}
\alias{GetScoresWeightsMatrix}
\title{get scores weight matrix}
\usage{
GetScoresWeightsMatrix(matrixOfPossibleValues, predictionDataStats,
  experimentalDataStats, logOfFactorialOfPredictionListStats)
}
\arguments{
\item{matrixOfPossibleValues}{values of n++, n+-, n-+ and n-- that need to be assessed}

\item{predictionDataStats}{a table of predicions}

\item{experimentalDataStats}{a table of observed experimental data}

\item{logOfFactorialOfPredictionListStats}{a vector containing the log of the factorial value for
each entry in predictionListStats}
}
\value{
a matrix containing scores and logs of the weights
}
\description{
Computes the score and weight for a network/set of experimental data based on the table containing possible values of n++, n+-, n-+ and n--.
}

