% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetSetOfDifferentiallyExpressedGenes.r
\name{GetSetOfDifferentiallyExpressedGenes}
\alias{GetSetOfDifferentiallyExpressedGenes}
\title{get set of differientially expressed genes}
\usage{
GetSetOfDifferentiallyExpressedGenes(results)
}
\arguments{
\item{results}{a table of results}
}
\value{
a matrix of differentially expressed genes
}
\description{
Gets the set of differentially expressed genes in the results, G+ as defined by in Causal reasoning on biological networks: Interpreting transcriptional changes,  L Chindelevitch et al.
}
\references{
L Chindelevitch et al.
Causal reasoning on biological networks: Interpreting transcriptional changes.
Bioinformatics, 28(8):1114-21, 2012.
}

