% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetWeightsAboveHypothesisScoreForAThreeByTwoTable.r
\name{GetWeightsAboveHypothesisScoreForAThreeByTwoTable}
\alias{GetWeightsAboveHypothesisScoreForAThreeByTwoTable}
\title{updates weights for contingency table and produce values for p-value calculation}
\usage{
GetWeightsAboveHypothesisScoreForAThreeByTwoTable(weights, r_p, r_m, r_z, n_p,
  n_m, predictionListStats, experimentalDataStats,
  logOfFactorialOfPredictionListStats, hypothesisScore, logepsDMax, logDMax)
}
\arguments{
\item{weights}{Weights}

\item{r_p}{the row sum r+}

\item{r_m}{the row sum r-}

\item{r_z}{the row sum r0}

\item{n_p}{the column sum n+}

\item{n_m}{the column sum n-}

\item{predictionListStats}{a list of prediction statistics}

\item{experimentalDataStats}{the observed experimental data}

\item{logOfFactorialOfPredictionListStats}{log factorial's of prediction list stats}

\item{hypothesisScore}{the hypothesis score to be considered}

\item{logepsDMax}{log of epsilon logD Maximum value}

\item{logDMax}{a logD Maximum value}
}
\value{
a vector containing the hypothesis score and the total weight
}
\description{
Finds the D-Values (weights) from any 3x2 contingency tables 
that have a score above and including the hypothesis score. It also calculates the
total weight, and returns a 2x1 vector of the two values. The ratio of these values is the p-value.
}

