% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetAllPossibleRoundingCombinations.r
\name{GetAllPossibleRoundingCombinations}
\alias{GetAllPossibleRoundingCombinations}
\title{get score for numbers of correct and incorrect predictions}
\usage{
GetAllPossibleRoundingCombinations(twoByTwoContingencyTable)
}
\arguments{
\item{twoByTwoContingencyTable}{Approximate values of n++, n+-, n-+ and n--, these values are
calculated to optimise the D-value (see page 6 of Assessing
statistical significance of causal graphs)}
}
\value{
a matrix of rounding combinations
}
\description{
Returns all possible rounding combinations of a 2x2 table. 
Given the values of n++, n+-, n-+ and n-- (stored in twoByTwoContingencyTable) this function will
compute all possibilities of rounding each value up or down.
}

