% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PopulateTheThreeByThreeContingencyTable.r
\name{PopulateTheThreeByThreeContingencyTable}
\alias{PopulateTheThreeByThreeContingencyTable}
\title{populate the three-by-three contingency table}
\usage{
PopulateTheThreeByThreeContingencyTable(n_pp, n_pm, n_mp, n_mm,
  predictionDataStats, experimentalDataStats)
}
\arguments{
\item{n_pp}{n++ contingency table entry}

\item{n_pm}{n+- contingency table entry}

\item{n_mp}{n-+ contingency table entry}

\item{n_mm}{n-- contingency table entry}

\item{predictionDataStats}{a prediction data table.}

\item{experimentalDataStats}{an experimental data table}
}
\value{
Vector of calculated values for n0+, n0-, n+0, n-0 and n00 - See: Chindelevitch et al.Bioinformatics (2012).
}
\description{
Populates 3x3 signed contingency table of expected versus observed changes.
Given the values of n++, n+-, n-+ and n--, calculates n0+, n0-, n+0, n-0 and n00. 
Notation from Chindelevitch et al. Causal reasoning on biological networks 
Bioinformatics (2012) paper.
}

