% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ProcessExperimentalData.r
\name{ProcessExperimentalData}
\alias{ProcessExperimentalData}
\title{process experimental data}
\usage{
ProcessExperimentalData(experimentalData, network)
}
\arguments{
\item{experimentalData}{input experimental data.}

\item{network}{an input interaction network.}
}
\value{
processed experimental data formatted ready for scoring
}
\description{
Processes experimental data to get it into the correct form
for scoring. The node names that are read in as strings acquire 
an internal id when the network is created. This function will 
replace the node name with its id.
}

