% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RemoveIDsNotInExperimentalData.r
\name{RemoveIDsNotInExperimentalData}
\alias{RemoveIDsNotInExperimentalData}
\title{remove IDs not in experimental data}
\usage{
RemoveIDsNotInExperimentalData(connectedNodes, nodesInExperimentalData)
}
\arguments{
\item{connectedNodes}{a list of connected nodes}

\item{nodesInExperimentalData}{a list of nodes in the experimental data}
}
\value{
connectedNodesInExperimentalData a list of connected nodes with the redundant nodes removed
}
\description{
Takes in a list of connected nodes and removes those not in the experimental data.
}

