% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetScoresWeightsMatrixByCubicAlg.r
\name{GetScoresWeightsMatrixByCubicAlg}
\alias{GetScoresWeightsMatrixByCubicAlg}
\title{get scores weights matrix by the cubic algorithm}
\usage{
GetScoresWeightsMatrixByCubicAlg(predictionListStats, experimentalDataStats,
  epsilon)
}
\arguments{
\item{predictionListStats}{a vector containing the values q+, q- and q0}

\item{experimentalDataStats}{a vector containing the values n+, n- and n0}

\item{epsilon}{the algorithms tolerance epsilon}
}
\value{
a matrix containing the ternary dot product distribution
}
\description{
Implements the cubic algorithm as described on pages 6 and 7 of Assessing statistical significance in causal graphs,
Chindelevitch et al. 2012
}
\references{
L Chindelevitch et al.
Assessing statistical significance in causal graphs.
BMC Bioinformatics, 13(35), 2012.
}

