% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DetermineInteractionTypeOfPath.r
\name{DetermineInteractionTypeOfPath}
\alias{DetermineInteractionTypeOfPath}
\title{determine interaction type of path}
\usage{
DetermineInteractionTypeOfPath(network, nodesInPath)
}
\arguments{
\item{network}{an igraph representing the network}

\item{nodesInPath}{an ordered list of the nodes visited on the path - note that these contain numbers which use 
R's internal reference to the edges}
}
\value{
a signed integer representing the paths sign
}
\description{
Determines the sign of a given path.
Given a path and through the network, this function will determine if the path results in activation or inhibition.
Activation is indicated by 1, inhibition by -1
}

