% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetRowAndColumnSumValues.r
\name{GetRowAndColumnSumValues}
\alias{GetRowAndColumnSumValues}
\title{get row and column sum values}
\usage{
GetRowAndColumnSumValues(predictionListStats, experimentalResultStats)
}
\arguments{
\item{predictionListStats}{a vector containing the number of postive, negative, or non-signficant/contradictory predictions (q+, q- and q0)}

\item{experimentalResultStats}{a vector containing the number of postive, negative, or non-signficant/contradictory observations (n+, n- and n0)}
}
\value{
a matrix of row and sum values r+, r-, c+ and c-
}
\description{
Returns the possible values of r+, r-, c+ and c- (the column and row sum values) following page 6 of Assessing
statistical  significance in causal graphs (Chindelevitch et. al)
}
\references{
L Chindelevitch et al.
Assessing statistical significance in causal graphs.
BMC Bioinformatics, 13(35), 2012.
}

