% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetSetOfSignificantPredictions.r
\name{GetSetOfSignificantPredictions}
\alias{GetSetOfSignificantPredictions}
\title{get set of significant predictions}
\usage{
GetSetOfSignificantPredictions(predictions)
}
\arguments{
\item{predictions}{a table of predictions}
}
\value{
a matrix of positive and negative predictions
}
\description{
Gets the set of positive and negative predictions, the combination of the sets Sh+ and Sh- in Causal reasoning on biological networks: Interpreting transcriptional changes,  L Chindelevitch et al.
}
\references{
L Chindelevitch et al.
Causal reasoning on biological networks: Interpreting transcriptional changes.
Bioinformatics, 28(8):1114-21, 2012.
}

