% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetMatrixOfCausalRelationships.r
\name{GetMatrixOfCausalRelationships}
\alias{GetMatrixOfCausalRelationships}
\title{compute causal relationships matrix}
\usage{
GetMatrixOfCausalRelationships(hypothesis, network,
  idsOfConnectedNodesFromSubgraph)
}
\arguments{
\item{hypothesis}{a hypothesis node}

\item{network}{a CCG network}

\item{idsOfConnectedNodesFromSubgraph}{a list of connected nodes in the subgraph of interest}
}
\value{
causal relationships matrix
}
\description{
Get a matrix of causal relationships from the network and the IDs of connected nodes
}

