% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/runRankHypothesis.r
\name{runRankHypothesis}
\alias{runRankHypothesis}
\title{run rank the hypothesis}
\usage{
runRankHypothesis(PPInet, Expressiondata, delta, correctPredictionsThreshold)
}
\arguments{
\item{PPInet}{PPInet is the PPI interaction file}

\item{Expressiondata}{observed gene expression data}

\item{delta}{the number of links to follow from any hypothesis no. Dedepending on network size/topology, this value typically ranges between 1 and 5}

\item{correctPredictionsThreshold}{Minimal score for p-values calculation. Hypotheses with scores below this value will get NAs for p-value and enrichment p-value. The usual default is -inf within the RankTheHypotheses function, where it is employed.}
}
\value{
rankedHypothesis table of results produced by the algorithm
}
\description{
A top level function that used to run CausalR
}

