% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetPathsInSifFormat.r
\name{GetPathsInSifFormat}
\alias{GetPathsInSifFormat}
\title{Get paths in Sif format}
\usage{
GetPathsInSifFormat(arrayOfPaths)
}
\arguments{
\item{arrayOfPaths}{an array of paths (in the format outputted by GetShortestPathsFromCCG) to be converted to .sif format}
}
\value{
network visualisation
}
\description{
Converts network paths into Simple interaction file (.sif) format for importing into Cytoscape
}

