% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AddWeightsToEdges.r
\name{AddWeightsToEdges}
\alias{AddWeightsToEdges}
\title{add weights to edges}
\usage{
AddWeightsToEdges(network, tableOfInteractions)
}
\arguments{
\item{network}{an igraph constructed from the original .sif file}

\item{tableOfInteractions}{a column of the corresponding .sif file indicating the direction of activation/interaction}
}
\value{
an augmented network
}
\description{
Adds weight information to the edges of given network (1 for activation and -1 for inhibition)
}

