% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetNodeID.r
\name{GetNodeID}
\alias{GetNodeID}
\title{get CCG node ID}
\usage{
GetNodeID(network, nodename, direction = 1)
}
\arguments{
\item{network}{a CCG object}

\item{nodename}{the node name, or names, for which the ID is required}

\item{direction}{the direction of regulation of the required node or nodes. Maybe +1 (default) or -1.}
}
\value{
a scalar or vector containing the node ID or IDs requested
}
\description{
Returns the CCG node ID from a node name or a vector of node names and a given direction of regulation.
}

