% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetWeightForNumbersOfCorrectandIncorrectPredictions.r
\name{GetWeightForNumbersOfCorrectandIncorrectPredictions}
\alias{GetWeightForNumbersOfCorrectandIncorrectPredictions}
\title{get weight for numbers of correct and incorrect predictions}
\usage{
GetWeightForNumbersOfCorrectandIncorrectPredictions(n_pp, n_pm, n_mp, n_mm,
  predictionDataStats, experimentalDataStats,
  logOfFactorialOfPredictionListStats, returnlog = FALSE)
}
\arguments{
\item{n_pp}{the contingency table entry n++}

\item{n_pm}{the contingency table entry n+-}

\item{n_mp}{the contingency table entry n-+}

\item{n_mm}{the contingency table entry n--}

\item{predictionDataStats}{prediction data statistics}

\item{experimentalDataStats}{experimental data statistics}

\item{logOfFactorialOfPredictionListStats}{log of factorial of prediction list stats}

\item{returnlog}{true if the result should be returned as a log}
}
\value{
none
}
\description{
Gets the weight based on the values of n++, n+-, n-+ and n--.
}

