% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ValidateFormatOfTable.r
\name{ValidateFormatOfTable}
\alias{ValidateFormatOfTable}
\title{validate format of table}
\usage{
ValidateFormatOfTable(dataTable)
}
\arguments{
\item{dataTable}{the table to be tested}
}
\value{
true if the test is satisfed.
}
\description{
Checks the format of the loaded in data. In particular exepects a table with threecolumns (in order) a initiating gene, an interaction ('Activates','Inhibits') and a responding gene and checks the number of rows and the values of the middle column.
}

