% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FindIdsOfConnectedNodesInSubgraph.r
\name{FindIdsOfConnectedNodesInSubgraph}
\alias{FindIdsOfConnectedNodesInSubgraph}
\title{find Ids of connected nodes in subgraph}
\usage{
FindIdsOfConnectedNodesInSubgraph(idsOfConnectedNodes, subgraphOfConnectedNodes)
}
\arguments{
\item{idsOfConnectedNodes}{a list of connected nodes in the full graph}

\item{subgraphOfConnectedNodes}{a subgraph}
}
\value{
a list of connected nodes in the subgraph
}
\description{
Adds the IDs of the connected nodes in a subgraph to an existing list. 
Given the IDs of connected nodes in the full network, this function will find
the corresponding IDs in the subgraph
}

