% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetInteractionInformation.r
\name{GetInteractionInformation}
\alias{GetInteractionInformation}
\title{returns interaction information from input data}
\usage{
GetInteractionInformation(dataTable)
}
\arguments{
\item{dataTable}{a data table containing the information read in from the .sif file representing the network.}
}
\value{
a vector of interaction information
}
\description{
Gets the interaction information from the input data
}

