% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/OrderHypotheses.r
\name{OrderHypotheses}
\alias{OrderHypotheses}
\title{order hypotheses}
\usage{
OrderHypotheses(scoresMatrix)
}
\arguments{
\item{scoresMatrix}{a matrix containing the scores for each node of the network}
}
\value{
a ranked table of hypotheses
}
\description{
Ranks the hypotheses.  Takes a matrix containing the scores for each node of the network, and ranks them placing the hypothesis with the 
most correct predictions is at the top
}

