% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetRegulatedNodes.r
\name{GetRegulatedNodes}
\alias{GetRegulatedNodes}
\title{get regulated nodes}
\usage{
GetRegulatedNodes(PPInet, Expressiondata, delta, hypothesisGene = "",
  signOfHypothesis = 1, outputfile = "")
}
\arguments{
\item{PPInet}{a protein-protein interaction network}

\item{Expressiondata}{a table of observed gene expression data}

\item{delta}{the number of edges to follow along the network. This should typically be between 1 and 5 dependent on network size/topology}

\item{hypothesisGene}{the name of the hypothesis gene}

\item{signOfHypothesis}{the sign of action expected from the hypothesis, +1 for up regulation, -1 for down}

\item{outputfile}{the file to which the results should be written}
}
\value{
Nodes regulated by hypothesis gene
}
\description{
This function will compute the nodes regulated by the given hypothesis gene and write the results to a file
}

