% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetWeightsAboveHypothesisScoreAndTotalWeights.r
\name{GetWeightsAboveHypothesisScoreAndTotalWeights}
\alias{GetWeightsAboveHypothesisScoreAndTotalWeights}
\title{get weights above hypothesis score and total weights}
\usage{
GetWeightsAboveHypothesisScoreAndTotalWeights(r_p, r_m, c_p,
  predictionListStats, experimentalDataStats,
  logOfFactorialOfPredictionListStats, hypothesisScore, logepsDMax, logDMax)
}
\arguments{
\item{r_p}{the row sum r+}

\item{r_m}{the row sum r-}

\item{c_p}{the column sum c+}

\item{predictionListStats}{statistics for the  prediction list}

\item{experimentalDataStats}{statistics for the experimental data}

\item{logOfFactorialOfPredictionListStats}{log of factorial of prediction list stats}

\item{hypothesisScore}{the hypothesis score to be considered}

\item{logepsDMax}{Exponential of logD Maximum value}

\item{logDMax}{A logD Maximum value}
}
\value{
score data
}
\description{
Gets the score based on the values of n++, n+-, n-+ and n--. Used as part of a p-value calculation.
}

