% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ReadSifFileToTable.r
\name{ReadSifFileToTable}
\alias{ReadSifFileToTable}
\title{read .sif to Table}
\usage{
ReadSifFileToTable(sifFile)
}
\arguments{
\item{sifFile}{the sifFile to be read in}
}
\value{
a R table containing the data from the .sif file
}
\description{
Reads a .sif file into a table in R
}

