% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FindMaximumDValue.r
\name{FindMaximumDValue}
\alias{FindMaximumDValue}
\title{find maximum D value}
\usage{
FindMaximumDValue(predictionListStats, experimentalDataStats,
  logOfFactorialOfPredictionListStats, returnlog = FALSE)
}
\arguments{
\item{predictionListStats}{a vector containing the predicted values q+, q- and q0:
numbers of positive, negative and non-significant/contradictory predictions}

\item{experimentalDataStats}{A vector containing the observed values n+, n- and n0:
numbers of positive, negative and non-significant/contradictory observations}

\item{logOfFactorialOfPredictionListStats}{a vector containing the log of the factorial value for
each entry in predictionListStats}

\item{returnlog}{should the result be returned as a log; default FALSE}
}
\value{
the maximum possible D value
}
\description{
computes the maximum possible D-value 
for given values q+, q-, q0 and n+, n-, n0.
}

