% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AddIDsToVertices.r
\name{AddIDsToVertices}
\alias{AddIDsToVertices}
\title{add IDs to vertices}
\usage{
AddIDsToVertices(network)
}
\arguments{
\item{network}{the network to which the IDs are to be added}
}
\value{
network with IDs added
}
\description{
Adds the IDs as a vertex property to 
the vertices in the network. Used when creating
sub-networks where the new nodes will retain the IDs from their original
network
}

