% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CheckRowAndColumnSumValuesAreValid.r
\name{CheckRowAndColumnSumValuesAreValid}
\alias{CheckRowAndColumnSumValuesAreValid}
\title{check row and column sum values are valid}
\usage{
CheckRowAndColumnSumValuesAreValid(rowAndColumnSumValues, predictionListStats,
  experimentalResultStats)
}
\arguments{
\item{rowAndColumnSumValues}{a 4x1 vector containing the row and column sum values (r+, r-, c+, c-) for a 2x2 contingency table}

\item{predictionListStats}{a vector containing the values q+, q- and q0}

\item{experimentalResultStats}{A vector containing the values n+, n- and n0}
}
\value{
TRUE if the table is valid; otherwise FALSE
}
\description{
Checkes to see if the values of r+, r-, c+ and c- which are stored in rowAndColumnSumValues define a valid contingency
table
}

