% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CreateCG.r
\name{CreateCG}
\alias{CreateCG}
\title{create a Computational Graph (CG)}
\usage{
CreateCG(sifFile)
}
\arguments{
\item{sifFile}{the path of the .sif file that contains all 
the information about the network Load in .sif file}
}
\value{
a CG network
}
\description{
Creates a CG network from a .sif file.
Takes in a .sif file output from Cytoscape, and creates an 'igraph' representing the network.
The edges will be annotated with the type of interaction and a weight (1 for activation and -1 for inhibition)
}
\examples{
# get path to example .sif file
network <- system.file(package='CausalR', 'extdata', 'testNetwork.sif')
#create cg
cg = CreateCG(network)
}
\concept{
CausalR
}

