% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PlotGraphWithNodeNames.r
\name{PlotGraphWithNodeNames}
\alias{PlotGraphWithNodeNames}
\title{plot graph with node names}
\usage{
PlotGraphWithNodeNames(igraph)
}
\arguments{
\item{igraph}{internal an igraph representation of an interaction network}
}
\value{
network visualisation
}
\description{
Plots an igraph with the node names. Plots a igraph to the screen displaying the names of the nodes input rather than R's internal numbering.
}
\examples{
network <- system.file(package='CausalR', 'extdata', 'testNetwork.sif')
ccg <- CreateCCG(network)
PlotGraphWithNodeNames(ccg)
}
\concept{
CausalR
}

