% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CalculateEnrichmentPValue.r
\name{CalculateEnrichmentPValue}
\alias{CalculateEnrichmentPValue}
\title{calculates an enrichment p-value}
\usage{
CalculateEnrichmentPValue(predictions, results)
}
\arguments{
\item{predictions}{predictions of changes from the CCG for a particular hypothesis}

\item{results}{gene changes observed in the experimental data}
}
\value{
an enrichment p-value
}
\description{
Calculate a enrichment p-value for a given hypothesis by comparing the corresponding predicted and observed gene changes
}
\examples{
predictions <- matrix(c(1,2,3,1,1,-1), ncol = 2)
results<- matrix(c(1,2,3,4,1,1,-1,1), ncol = 2)
CalculateEnrichmentPValue(predictions, results)
}
\concept{
CausalR
}

