% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AnalyseExperimentalData.r
\name{AnalyseExperimentalData}
\alias{AnalyseExperimentalData}
\title{analyse experimental data}
\usage{
AnalyseExperimentalData(experimentalData)
}
\arguments{
\item{experimentalData}{a dataframe containing a list of genes with corresponding direction of change (1 or -1)}
}
\value{
up and down regulation statistics for the experimental data
}
\description{
Returns the number of up- and down-regulated genes in the experimental data
}

