% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetCombinationsOfCorrectandIncorrectPredictions.r
\name{GetCombinationsOfCorrectandIncorrectPredictions}
\alias{GetCombinationsOfCorrectandIncorrectPredictions}
\title{returns table of correct and incorrect predictions}
\usage{
GetCombinationsOfCorrectandIncorrectPredictions(predictionDataStats,
  experimentalDataStats)
}
\arguments{
\item{predictionDataStats}{prediction data statistics table}

\item{experimentalDataStats}{Experimental data statistics table}
}
\value{
a matrix the  numbers of correct and incorrect positive and negative prediction
}
\description{
Returns the  numbers of correct and incorrect positive and negative predictions
}

