% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ScoreHypothesis.r
\name{ScoreHypothesis}
\alias{ScoreHypothesis}
\title{score hypothesis}
\usage{
ScoreHypothesis(matrixOfPredictions, matrixOfExperimentalData)
}
\arguments{
\item{matrixOfPredictions}{a matrix of predictions}

\item{matrixOfExperimentalData}{a matrix of experimentaldata}
}
\value{
scoreBreakdown a vector giving, in order, the overall score, and the numbers of correct, incorrect and ambigous predictions
}
\description{
Score a single hypothesis, using the predictions from the network and the experimental data returning a vector of scoring statistics
}
\examples{
predictions <- matrix(c(1,2,3,+1,0,-1),ncol=2)
experimentalData <- matrix(c(1,2,4,+1,+1,-1),ncol=2)
ScoreHypothesis(predictions,experimentalData)
CompareHypothesis(predictions,experimentalData)
}
\concept{
CausalR
}

