% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetMaxDValueForAFamily.r
\name{GetMaxDValueForAFamily}
\alias{GetMaxDValueForAFamily}
\title{get maximun D value for a family}
\usage{
GetMaxDValueForAFamily(r_p, r_m, c_p, predictionListStats,
  experimentalDataStats, logOfFactorialOfPredictionListStats,
  returnlog = FALSE)
}
\arguments{
\item{r_p}{row sum r+}

\item{r_m}{row sum r-}

\item{c_p}{column sum c+}

\item{predictionListStats}{approximate values of n++, n+-, n-+ and n--}

\item{experimentalDataStats}{a vector containing the values q+, q- and q0:  number of positive, negative, non-significant/contradictory predictions}

\item{logOfFactorialOfPredictionListStats}{a vector containing the values n+, n- and n0:  number of positive, negative, non-significant/contradictory observations}

\item{returnlog}{return result as log, default value is FALSE}
}
\value{
the maximum DFam Value
}
\description{
Computes the maximum D value for a particular family - denoted as D_fam on page 6 of Assessing Statistical Signifcance of Causal Graphs
}
\references{
L Chindelevitch et al.
Assessing statistical significance in causal graphs.
BMC Bioinformatics, 13(35), 2012.
}

