% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PopulateTwoByTwoContingencyTable.r
\name{PopulateTwoByTwoContingencyTable}
\alias{PopulateTwoByTwoContingencyTable}
\title{Populate Two by Two Contingency Table}
\usage{
PopulateTwoByTwoContingencyTable(rowAndColumnSumValues, n_pp)
}
\arguments{
\item{rowAndColumnSumValues}{the row and column sums (r+, r-, c+, c-).}

\item{n_pp}{the value of n++.}
}
\value{
the completed 2x2 contingency table: n++, n+-, n-+, n--
}
\description{
Calculates a 2x2 contingency table.
Given the value of n++ and the row and column sums (r+, r-, c+, c-),
Calculates the remaining values in the 2x2 contingency table i.e.
n+-, n-+, and n--. See Chindelevich et al. BMC Bioinformatics (2012) paper 
'Assessing Statistical significance of causal graphs' for clarification on notation.
}
\references{
L Chindelevitch et al.
Causal reasoning on biological networks: Interpreting transcriptional changes.
Bioinformatics, 28(8):1114-21, 2012.
}

