% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetWeightsFromInteractionInformation.r
\name{GetWeightsFromInteractionInformation}
\alias{GetWeightsFromInteractionInformation}
\title{get weights from interaction information}
\usage{
GetWeightsFromInteractionInformation(interactionInfo)
}
\arguments{
\item{interactionInfo}{a central column of the .sif file, giving the type of edge interaction}
}
\value{
a matrix of weights corresponding the the direction of regulation
}
\description{
Returns a matrix of weights (-1,0,+1) indicating the direction of regulation from the interaction information.
}

