% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ComputePValueFromDistributionTable.r
\name{ComputePValueFromDistributionTable}
\alias{ComputePValueFromDistributionTable}
\title{compute a p-value from the distribution table}
\usage{
ComputePValueFromDistributionTable(scoreOfHypothesis, distributionMatrix,
  totalWeights)
}
\arguments{
\item{scoreOfHypothesis}{a score of hypothesis}

\item{distributionMatrix}{a distribution table presented as a matrix}

\item{totalWeights}{a matrix of total weights}
}
\value{
a p-value
}
\description{
Computes the p-value of the score of an hypothesis, based on a distribution table
}

