% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CreateNetworkFromTable.r
\name{CreateNetworkFromTable}
\alias{CreateNetworkFromTable}
\title{create network from table}
\usage{
CreateNetworkFromTable(dataTable)
}
\arguments{
\item{dataTable}{the data table containing the information read in from the .sif file representing the network.}
}
\value{
an igraph network
}
\description{
Creates a network from an internal data table created from a .sif file:
this function converts the data read in from the .sif file into 
an igraph in R.
}

