% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetScoreForNumbersOfCorrectandIncorrectPredictions.r
\name{GetScoreForNumbersOfCorrectandIncorrectPredictions}
\alias{GetScoreForNumbersOfCorrectandIncorrectPredictions}
\title{returns the score for a given number of correct and incorrect predictions}
\usage{
GetScoreForNumbersOfCorrectandIncorrectPredictions(matrixRow)
}
\arguments{
\item{matrixRow}{a row af a matrix of correct and incorrect prediction scores}
}
\value{
the corresponding score for the given row
}
\description{
Returns the score based on the values of n++, n+-, n-+ and n--
}

